vitamin d: info: https://ods.od.nih.gov/factsheets/VitaminD-HealthProfessional/ https://en.wikipedia.org/wiki/Vitamin_D purposes: maintenance of adequate serum calcium and phosphate concentrations proposals: https://en.wikipedia.org/wiki/Vitamin_D#Dietary_intake sources: mushrooms: crimini: https://fdc.nal.usda.gov/fdc-app.html#/food-details/2003601/nutrients lions mane: https://fdc.nal.usda.gov/fdc-app.html#/food-details/1999626/nutrients maybe: { "names": [ "vitamin d" ] "unites": [ "vitamin d (d2 + d3)", "vitamin d1", "vitamin d2", "vitamin d3", "vitamin d4", "vitamin d5" ] } kinds: { "names": [ "vitamin d (d2 + d3)", "vitamin d2 & d3", "vitamin d2 + d3", "vitamin d2 and d3" ], "unites": [] } { "names": [ "vitamin d2", "ergocalciferol", "calciferol" ], "formula": { "composition": [ [ "C", 28 ], [ "H", 44 ] [ "O", 1 ] ] }, "unites": [] } { "names": [ "vitamin d3", "cholecalciferol" ], "unites": [] } { "names": [ "vitamin d4", "22-dihydroergocalciferol" ], "unites": [] } { "names": [ "vitamin d5", "7-dehydrositosterol" ], "unites": [] }